__version__: str

class ClipboardError(RuntimeError): ...

def copy(
    data: None
    | str
    | tuple[int, int, bytes]
    | os.PathLike[str]
    | os.PathLike[bytes]
    | list[os.PathLike[str] | os.PathLike[bytes] | str],
    /,
) -> None: ...
def paste() -> str | dict[str, object] | list[str]: ...
def clear() -> None: ...



"""Cross-platform clipboard access with zero external dependencies."""

from __future__ import annotations

from ._core import (
    ClipboardError,
    __version__,
    clear,
    copy,
    paste,
)

__all__ = [
    "__version__",
    "ClipboardError",
    "clear",
    "copy",
    "paste",
]
